@@ -2,6 +2,7 @@
 #define KIWIXLIB_KIWIX_SERVE_H_
 
 #include <memory>
+#include <string>
 
 class Subprocess;
 namespace kiwix {
@@ -9,7 +10,7 @@ namespace kiwix {
 class KiwixServe
 {
   public:
-    KiwixServe(int port = 8181);
+    KiwixServe(const std::string& libraryPath, int port = 8181);
     ~KiwixServe();
 
     void run();
@@ -20,6 +21,7 @@ class KiwixServe
   private:
   std::unique_ptr<Subprocess> mp_kiwixServe;
   int m_port;
+  std::string m_libraryPath;
 };
 
 }; //end namespace kiwix
