@@ -19,11 +19,13 @@
 
 #include "library.h"
 #include "book.h"
+#include "reader.h"
 #include "libxml_dumper.h"
 
 #include "tools/base64.h"
 #include "tools/regexTools.h"
 #include "tools/pathTools.h"
+#include "tools/stringTools.h"
 
 #include <pugixml.hpp>
 #include <algorithm>
@@ -31,6 +33,7 @@
 
 namespace kiwix
 {
+
 /* Constructor */
 Library::Library()
 {
@@ -82,6 +85,20 @@ Book& Library::getBookById(const std::string& id)
   return m_books.at(id);
 }
 
+std::shared_ptr<Reader> Library::getReaderById(const std::string& id)
+{
+  try {
+    return m_readers.at(id);
+  } catch (std::out_of_range& e) {}
+
+  auto book = getBookById(id);
+  if (!book.isPathValid())
+    return nullptr;
+  auto sptr = make_shared<Reader>(book.getPath());
+  m_readers[id] = sptr;
+  return sptr;
+}
+
 unsigned int Library::getBookCount(const bool localBooks,
                                    const bool remoteBooks)
 {
